dispatch_organ_symbol

Function dispatch_organ_symbol 

pub fn dispatch_organ_symbol() -> Symbol
Symbol identifying the dispatch organ in the claim store.

Used as the claim subject when publishing the organ’s contributed operations into a Cx.