pub fn generic_function_value(
cx: &mut Cx,
generic: GenericFunction,
) -> Result<Value>Expand description
Wraps generic as a runtime callable value that dispatches most-specific.
pub fn generic_function_value(
cx: &mut Cx,
generic: GenericFunction,
) -> Result<Value>Wraps generic as a runtime callable value that dispatches most-specific.